@@ -212,7 +212,7 @@ gwget_data_update_statistics (GwgetData *gwgetdata)
 			   -1);
 		
 	gwget_data_update_statistics_ui(gwgetdata);
-	if (gwgetdata == gwget_data_get_selected()) {
+	if (gwgetdata == gwget_data_get_selected() || count_download_in_progress() == 1 ) {
 		gtk_window_set_title(GTK_WINDOW(glade_xml_get_widget(xml, "main_window")), title);
 	}
 
@@ -244,8 +244,7 @@ gwget_data_update_statistics_ui(GwgetData *gwgetdata)
 				   if (gwget_pref.docked) {
 					   tooltip_message=g_strdup_printf(_("Download Completed\n(%s)"), 
 							   gwgetdata->url);
-					   gtk_tooltips_set_tip (GTK_TOOLTIPS(tray_tooltip), GTK_WIDGET(tray_icon),tooltip_message,NULL);
-					   egg_tray_icon_send_message(tray_icon,100000,tooltip_message,strlen(tooltip_message));
+					   gtk_tooltips_set_tip (GTK_TOOLTIPS(tray_tooltip), GTK_WIDGET(tray_icon), tooltip_message,NULL);
 					   set_icon_idle();
 				   }
 					   
@@ -290,7 +289,7 @@ gwget_data_process_information (GwgetData *gwgetdata)
 		else if (WIFEXITED (status)) {
             		if (WEXITSTATUS (status) == 0) {
                 		gwget_data_set_state (gwgetdata, DL_COMPLETED);
-                     gwget_gnotify_finished(gwgetdata);
+                     		gwget_gnotify_finished(gwgetdata);
 				start_first_waiting_download();
 				if (gwget_pref.open_after_dl) {
 					gwget_data_exec(gwgetdata);
@@ -507,6 +506,13 @@ gwget_data_set_total_size (GwgetData *gwgetdata, guint64 total_size)
 	gwgetdata->total_size = total_size;
 }
 
+GwgetData *
+gwget_data_new (gchar *url)
+{
+
+	return gwget_data_create (url, gwget_pref.download_dir);
+
+}
 
 GwgetData * 
 gwget_data_create(gchar *url, gchar *dir)
@@ -610,7 +616,7 @@ void gwget_data_stop_download(GwgetData *data)
 	
 	if (gwget_data_run(data)) {
 		/* Kill wget process */
-		kill (data->wget_pid, SIGINT);
+		kill (data->wget_pid, SIGKILL);
 		
 		/* Remove callback that communicates with wget */
 		gtk_timeout_remove (data->log_tag);
@@ -720,8 +726,8 @@ gwget_data_add_download(GwgetData *gwgetdata)
 		}
 	}
 	downloads = g_list_append(downloads,gwgetdata);
-	gwget_data_set_state(gwgetdata,DL_NOT_CONNECTED);
 	new_download(gwgetdata);
+	gwget_data_set_state(gwgetdata,DL_NOT_CONNECTED);
 }
 
 void
@@ -733,7 +739,7 @@ gwget_data_exec (GwgetData *gwgetdata)
 	uri = gnome_vfs_make_uri_from_input_with_dirs (gwgetdata->local_filename,
 							GNOME_VFS_MAKE_URI_DIR_CURRENT);
 	if (!gnome_url_show (uri, &err)) {
-		run_dialog(_("Error opening file"),_("Couldn't open the file"));
+		run_dialog_error(_("Error opening file"), _("Couldn't open the file"));
 	}
 }
 
@@ -771,10 +777,11 @@ gwget_gnotify_finished(GwgetData *gwgetdata) {
       close(sock);
    }
 
+   gwget_tray_notify (_("Download Complete"), gwgetdata->filename, gwgetdata->icon_name);
    g_free(app_msg);
    g_free(icon_msg);
    g_free(fn_msg);
-	g_free(gwgetdata->icon_name);
+   g_free(gwgetdata->icon_name);
 }
 
 void
